package net.wanji.opt.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import io.swagger.annotations.ResponseHeader;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.exception.DubboProviderException;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.dto.CrossIdAndMinutesDTO;
import net.wanji.opt.entity.EventAlarmInfo;
import net.wanji.opt.po.base.EventStatisticPo;
import net.wanji.opt.service.EvaluateService;
import net.wanji.opt.service.EventService;
import net.wanji.opt.vo.EvaluateCrossDetailVO;
import net.wanji.opt.vo.EvaluateMetricsVO;
import net.wanji.opt.vo.GreenWaveRunStateVO;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.ws.rs.core.MediaType;
import java.util.List;
import java.util.Map;


@RestController
@Slf4j
@RequestMapping("/event")
@Api(value="EventController", description="事件相关", tags = "事件相关")
public class EventController {

    @Resource
    EventService eventService;


    @GetMapping("/count")
    @ApiOperation(httpMethod="GET",value="事件总次数统计", notes="")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String",defaultValue = "13N8J0B5P10"),
            @ApiImplicitParam(name = "eventType", value = "事件类型 701:空放 702：失衡 703：溢出", required = true, dataType = "String",defaultValue = "701"),
            @ApiImplicitParam(name = "startTime", value = "截止时间，格式：yyyy-MM-dd HH:mm:ss", required = true, dataType = "String",defaultValue = "2025-01-05 00:00:00"),
            @ApiImplicitParam(name = "endTime", value = "截止时间，格式：yyyy-MM-dd HH:mm:ss", required = true, dataType = "String",defaultValue = "2025-01-05 23:59:59"),

    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功", response = EventStatisticPo.class,
                    responseHeaders = {@ResponseHeader(name = "Content-Type", description = "application/json")})
    })
    public JsonViewObject evaluateCrossDetail(String crossId,String eventType,String startTime,String endTime) {
        EventStatisticPo result = null;
        try {
            result = eventService.findCrossEventCount(crossId,eventType,startTime,endTime );
            return JsonViewObject.newInstance().success(result);
        } catch (DubboProviderException e) {
            e.printStackTrace();
            return JsonViewObject.newInstance().fail(e);
        }

    }

    @GetMapping("/distribute")
    @ApiOperation(httpMethod="GET",value="空放、失衡、溢出事件分布情况", notes="")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String",defaultValue = "13N8J0B5P10"),
            // @ApiImplicitParam(name = "eventType", value = "事件类型 701:空放 702：失衡 703：溢出", required = false, dataType = "String",defaultValue = "701"),
            @ApiImplicitParam(name = "startTime", value = "截止时间，格式：yyyy-MM-dd HH:mm:ss", required = true, dataType = "String",defaultValue = "2025-01-05 00:00:00"),
            @ApiImplicitParam(name = "endTime", value = "截止时间，格式：yyyy-MM-dd HH:mm:ss", required = true, dataType = "String",defaultValue = "2025-01-05 23:59:59"),

    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功", response = EventStatisticPo.class,
                    responseHeaders = {@ResponseHeader(name = "Content-Type", description = "application/json")})
    })
    public JsonViewObject distribute(String crossId,String startTime,String endTime) {

        try {
            List<Map<String,Object>> result = eventService.findEventDistribute(crossId,startTime,endTime );
            return JsonViewObject.newInstance().success(result);
        } catch (DubboProviderException e) {
            e.printStackTrace();
            return JsonViewObject.newInstance().fail(e);
        }

    }


    @GetMapping("/getAlarmInfo")
    @ApiOperation(hidden = false, value = "事件报警", notes = "", produces = "application/json")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "greenId", value = "绿波编号，指定干线编号时查询干线相关事件", required = false, dataType = "String"),
            @ApiImplicitParam(name = "crossId", value = "路口编号，指定路口编号时查询路口相关事件", required = false, dataType = "String"),
            @ApiImplicitParam(name = "type", value = "为1查询最近实时30条，为空时查询当天历史", required = false, dataType = "String")
    }
    )
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功", response = EventAlarmInfo.class,
                    responseHeaders = {@ResponseHeader(name = "Content-Type", description = "application/json")})
    })
    public JsonViewObject list(@RequestParam(defaultValue = "") Integer greenId, @RequestParam(defaultValue = "") String crossId , @RequestParam(defaultValue = "") String type) {
        try {
            JsonViewObject jsonViewObject = JsonViewObject.newInstance();
            List<EventAlarmInfo> eventAlarmInfo = eventService.findEventAlarmInfo(greenId,crossId,type);
            return jsonViewObject.success(eventAlarmInfo);
        } catch (Exception e) {
            log.error("", e);
            return JsonViewObject.newInstance().fail("请求失败");
        }

    }

}